app/soc/models/group_app.py
changeset 1085 0afbdd0905ef
parent 1080 d533408811ba
child 1199 4e69a5f30a9a
--- a/app/soc/models/group_app.py	Fri Jan 30 17:23:19 2009 +0000
+++ b/app/soc/models/group_app.py	Fri Jan 30 17:38:28 2009 +0000
@@ -98,9 +98,9 @@
   member_criteria.help_text = ugettext(
     'Members include mentors, admininstrators, and the like.')
 
   # property containing the state of the application
   # completed means that the application has been processed into a real group
-  state = db.StringProperty(required=True, 
+  status = db.StringProperty(required=True, 
       choices=['accepted','rejected','ignored','needs review','completed'],
       default='needs review',
       verbose_name=ugettext('Application Status'))
@@ -98,9 +98,9 @@
     'Members include mentors, admininstrators, and the like.')
 
-  # property containing the state of the application
+  # property containing the status of the application
   # completed means that the application has been processed into a real group